@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-'package for simple band-structure calculations and analysis'
-__version__ = '1.0'
-__author__ = 'Iacopo Torre, Pietro Novelli'
+"package for simple band-structure calculations and analysis"
+__version__ = "2.0"
+__author__ = "Iacopo Torre, Pietro Novelli"
 
 from pybandstructure.geometry import *
 from pybandstructure.sample import *
 from pybandstructure.operators import *
 from pybandstructure.band_structure import *
 from pybandstructure.crystal import *
-from pybandstructure.models import *
\ No newline at end of file
+from pybandstructure.models import *
